
# Slot: object


treatment whose efficacy is modulated by the subject variant

URI: [biolink:sequence_variant_modulates_treatment_association_object](https://w3id.org/biolink/vocab/sequence_variant_modulates_treatment_association_object)


## Domain and Range

[SequenceVariantModulatesTreatmentAssociation](SequenceVariantModulatesTreatmentAssociation.md) &#8594;  <sub>1..1</sub> [Treatment](Treatment.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [SequenceVariantModulatesTreatmentAssociation](SequenceVariantModulatesTreatmentAssociation.md)
